@@ -21,35 +21,31 @@ def read_parameters(input_file):
         index = string.find('=')+2
         lista.append(string[index:-1])
         
-    lattice_param = float(lista[1])
-    
-    m = lista[2]
+
+    m = lista[1]
     Masses = np.fromstring(m, dtype=np.float, sep=',')
     
-    ns = lista[3]
+    ns = lista[2]
     n_atom_unit_cell = np.fromstring(ns, dtype=np.int, sep=',')
     
-    ncs = lista[4]
-    n_atom_conventional_cell = np.fromstring(ncs, dtype=np.int, sep=',')
-    
-    N = lista[5]
+    N = lista[3]
     n = np.fromstring(N, dtype=np.int, sep=',')
     N1,N2,N3 = n[0],n[1],n[2]
     
-    band = lista[6]
+    band = lista[4]
     a = np.fromstring(band, dtype=np.float, sep=',')
     num = len(a)/3
     ks = np.split(a,num)
     
-    file_eigenvectors = str(lista[7])
+    file_FC = str(lista[5])
     
-    file_trajectory = str(lista[8])
+    file_trajectory = str(lista[6])
     
-    file_initial_conf = str(lista[9])
+    file_initial_conf = str(lista[7])
+    
+    DT = float(lista[8])
     
-    system = str(lista[10])
     
-    DT = float(lista[11])
 
             
 #    brchs = lista[14]
@@ -58,7 +54,7 @@ def read_parameters(input_file):
 #    max_Z = float(lista[15])
     
     f.close()
-    return lattice_param, Masses, n_atom_unit_cell, n_atom_conventional_cell, N1,N2,N3, ks, file_eigenvectors, file_trajectory, file_initial_conf, system, DT
+    return  Masses, n_atom_unit_cell, N1,N2,N3, ks, file_FC, file_trajectory, file_initial_conf, DT
 
 
 
@@ -72,44 +68,47 @@ def read_post_proc(input_file):
         index = string.find('=')+2
         lista.append(string[index:-1])
     
-    plot_types = np.fromstring(lista[1], dtype=np.int, sep=',')
+    plot_types = int(lista[1])#np.fromstring(lista[1], dtype=np.int, sep=',')
     
-    ns = lista[2]
-    n_atom_unit_cell = np.fromstring(ns, dtype=np.int, sep=',')
-    
-    m = lista[3]
+    m = lista[2]
     Masses = np.fromstring(m, dtype=np.float, sep=',')
     
-    file_eigenvectors = str(lista[4])
+    ns = lista[3]
+    n_atom_unit_cell = np.fromstring(ns, dtype=np.int, sep=',')
     
-    file_SPOSCAR = lista[5]
+    N = lista[4]
+    n = np.fromstring(N, dtype=np.int, sep=',')
+    N1,N2,N3 = n[0],n[1],n[2]
     
-    max_Z = float(lista[6])
+    file_forces = str(lista[5])
     
-    gaussian_smoothing = lista[7]
+    file_SPOSCAR = lista[6]
+    
+    max_Z = float(lista[7])
+    
+    gaussian_smoothing = lista[8]
     if(gaussian_smoothing=='auto'):
         gaussian_smoothing = -1
     else:
-        gaussian_smoothing = float(lista[7])
+        gaussian_smoothing = float(lista[8])
     
-    interp = int(lista[8])
+    interp = int(lista[9])
     
-    ks = lista[9]
+    ks = lista[10]
     a = np.fromstring(ks, dtype=np.float, sep=',')
     num = len(a)/3
     kpoints = np.split(a,num)
     
-    labs = lista[10]
+    labs = lista[11]
     labels = labs.split(',')
     
-    modes = np.fromstring(lista[11], dtype=np.int, sep=',')
+    modes = np.fromstring(lista[12], dtype=np.int, sep=',')
     
-    temperature_folders = lista[12]
+    temperature_folders = lista[13]
     
-    return plot_types, n_atom_unit_cell, Masses, file_eigenvectors, file_SPOSCAR, max_Z, gaussian_smoothing, interp, kpoints, labels, modes, temperature_folders
-
-
-
+    NAC = bool(int(lista[14]))
+     
+    return plot_types, Masses, n_atom_unit_cell, N1, N2, N3, file_forces, file_SPOSCAR, max_Z, gaussian_smoothing, interp, kpoints, labels, modes, temperature_folders, NAC
 
 
 
@@ -201,7 +200,7 @@ def read_phonopy(file_eigenvectors, n_atom_unit_cell):
     return Nqpoints, qpoints_scaled, ks, frequencies, eigvecs, distances, Hk
 
 
-def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell, Masses):
+def read_SPOSCAR_and_masses(file, n_atom_primitive_cell, Masses, N1, N2, N3):
     conv = np.genfromtxt(file, skip_header=1, max_rows=1)
     h = np.genfromtxt(file,skip_header=2, max_rows=3)
     S = np.genfromtxt(file, skip_header=8)
@@ -221,13 +220,15 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     R0 = np.dot(h,S.T).T*conv_factor
     
     Ruc = np.zeros((tot_atoms_primitive,3))
+    huc = h/np.array([N1,N2,N3])*conv_factor
     c = 0
-    for i in range(len(n_atom_conventional_cell)):
-        n = n_atom_conventional_cell[i]
+    for i in range(len(n_atom_primitive_cell)):
+        n = n_atom_primitive_cell[i]
         for j in range(n):
             Ruc[c+j] = R0[(c+j)*N1N2N3]
         c = c + j+1
-    R0 = np.repeat(R0,3,axis=0)
+    Suc = np.dot(np.linalg.inv(huc), Ruc.T).T
+    R0_repeat = np.repeat(R0,3,axis=0)
     
     
     repeated_masses = np.array([])
@@ -235,7 +236,7 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     for i in range(len(Masses)):
         mass = Masses[i]
 
-        n = n_atom_conventional_cell[i]
+        n = n_atom_primitive_cell[i]
         nprim = n_atom_primitive_cell[i]
         
         m = np.repeat(mass, N1N2N3*3*n)
@@ -247,7 +248,7 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
     masses = np.array(repeated_masses).flatten()
     masses_for_animation = np.array(repeated_masses_for_ani).flatten()
     
-    return h*conv_factor, Ruc, R0, masses, masses_for_animation
+    return h*conv_factor, Ruc, Suc, R0, R0_repeat, S, masses, masses_for_animation
 
 #h, Ruc, R0, masses, masses_for_animation = read_SPOSCAR_and_masses('../SPOSCAR_primitive', [1,1], [1,1], [1,1])
 #Cell = h/10
@@ -262,43 +263,25 @@ def read_SPOSCAR_and_masses(file, n_atom_conventional_cell,n_atom_primitive_cell
 #print(b2)
 #print(b3)
 
-def read_path(kinput_scaled, Nqpoints, labels, Hk):
-    Nq_input = len(kinput_scaled)
-    ks = []
-    x_labels = []
-    distances = []
-    previous_k = np.dot(Hk, kinput_scaled[0])
-    distance = 0.0
-    for i in range(Nq_input-1):
-        this_k_input = kinput_scaled[i]
-        next_k_input = kinput_scaled[i+1]
-        ks.append(this_k_input)
-        x_labels.append(labels[i])
-        direction_input = (next_k_input - this_k_input)/np.linalg.norm(next_k_input - this_k_input)
-        accepted_kinputs = []
-        for j in range(Nqpoints):
-            to_skip = (4)*j
-            this_k = np.genfromtxt('quasiparticles',skip_header=to_skip+0, max_rows=1)
-            direction = (this_k - this_k_input)/np.linalg.norm(this_k - this_k_input)
-            if(np.allclose(direction, direction_input) and not np.allclose(this_k, next_k_input)):
-                ks.append(this_k)
-                distance = distance + np.linalg.norm(np.dot(Hk,this_k) - previous_k)
-                distances.append(distance)
-                previous_k = np.dot(Hk,this_k)
-                x_labels.append(' ')
-            elif(np.allclose(this_k, this_k_input) and not this_k.tolist() in accepted_kinputs):
-                accepted_kinputs.append(this_k_input.tolist())
-                this_q = np.dot(Hk, this_k_input)
-                distance = distance + np.linalg.norm(this_q - previous_k)
-                distances.append(distance)  
-                previous_k = this_q
 
-    ks.append(kinput_scaled[-1])
-    x_labels.append(labels[-1])
-    distance = distance + np.linalg.norm(np.dot(Hk,kinput_scaled[-1])-previous_k)
-    distances.append(distance)
-    distances = np.array(distances)
-    return ks, x_labels, distances
+
+
+
+
+
+def read_FC(file):
+    tot_atoms_uc, N = np.genfromtxt(file,max_rows=1, dtype=int)
+    K = np.zeros((tot_atoms_uc*3,N*3))
+    
+    to_skip = 2
+    for i in range(tot_atoms_uc):
+        for j in range(N):
+            forces = np.genfromtxt(file,skip_header=to_skip, max_rows=3)
+            K[i*3:i*3+3,j*3:j*3+3] = forces
+            to_skip = to_skip+1+3
+    # ASAP's displacement is in Bohrs, but phonopy thinks they are A, so you do
+    # FC = Force / displ = (ev / A) / Bohr = ev / A**2 /0.52917
+    return K/0.529177249
 
 
 
