@@ -194,7 +194,7 @@ def get_irr_ks(ks, ks_scaled):
     
     accepted_same_ks_overall, index_irr_ks, weights, permutations_types = np.array([]), [], [], []
     for i in range(Nks):
-        if(np.isin(i, accepted_same_ks_overall)):
+        if(i in accepted_same_ks_overall.tolist()):
             # print('non irr k') #found non irreducible kpoint
             continue
         this_k = ks[i]
